@@ -1,3 +1,20 @@
+/*
+ * Copyright (C) 2014 Stuart Howarth <showarth@marxoft.co.uk>
+ *
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms and conditions of the GNU Lesser General Public License,
+ * version 3, as published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope it will be useful, but WITHOUT ANY
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
+ * more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
+ */
+
 #include "transfermanager.h"
 #include "definitions.h"
 #include "storage.h"
@@ -93,6 +110,7 @@ void TransferManager::startNextTransfers() {
 
     while ((active < MAX_CONCURRENT_TRANSFERS) && (i < m_transfers.size())) {
         if (m_transfers.at(i)->status() == FileTransfer::Queued) {
+            m_activeTransfers.append(m_transfers.at(i));
             m_transfers.at(i)->start();
             active++;
         }
@@ -104,10 +122,8 @@ void TransferManager::startNextTransfers() {
 void TransferManager::onTransferStatusChanged(FileTransfer::Status status) {
     if (FileTransfer *transfer = qobject_cast<FileTransfer*>(this->sender())) {
         switch (status) {
-        case FileTransfer::Connecting:
-        case FileTransfer::Downloading:
-        case FileTransfer::Uploading:
-            m_activeTransfers.append(transfer);
+        case FileTransfer::Queued:
+            m_queueTimer.start();
             return;
         case FileTransfer::Paused:
         case FileTransfer::Failed:
